.. Copyright 2012, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.

 
Getting started with Reahl
==========================

.. sidebar:: Other projects used

   You will need to understand a few other projects when using Reahl. 
   There's no need to rush off and learn them to follow the tutorial
   -- these are pointed out where they come into play.

   You probably know the important ones already:

    - `virtualenv <http://pypi.python.org/pypi/virtualenv>`_
    - `distribute <http://pypi.python.org/pypi/distribute>`_
    - `nosetests <https://nose.readthedocs.org/en/latest/>`_
    - `SqlAlchemy <http://www.sqlalchemy.org/>`_
    - `Alembic <https://pypi.python.org/pypi/alembic/>`_; and
    - `Elixir <http://elixir.ematia.de/trac/wiki>`_ (optional, but used
      in the tutorial).

   There are also projects that are used almost totally behind the
   scenes.  The most visible of these is a database back-end. For this
   purpose `SQLite <http://www.sqlite.org>`_ and `PostgreSQL
   <http://www.postgresql.org>`_ are currently supported. SQLite is
   used throughout the tutorial.


Follow this guide to get Reahl installed in your development
environment and to get a skeleton web application going.

This version of Reahl requires at least version 2.7 of Python. Check out
Reahl 3.0 and later for Python 3 support.

We have split the guide into parts:

.. toctree::

   gettingstarted-install
   gettingstarted-develop




